@@ -488,8 +488,9 @@ class Base(Controller):
     )
     def ssh(self):
         from ..ext.sshconf import read_ssh_config
+        ssh_config_path = os.path.expanduser('~/.ssh/config')
+
         if self.app.pargs.action=='set':
-            ssh_config_path = os.path.expanduser('~/.ssh/config')
             ssh_config_obj = read_ssh_config(ssh_config_path)
             ssh_config_obj.set(self.app.pargs.host, HostName=self.app.pargs.ip)
             ssh_config_obj.write(ssh_config_path)
@@ -500,10 +501,15 @@ class Base(Controller):
             profile ='default' # or  self.app.pargs
             print(update_ec2_ssh(profile))
 
+        elif self.app.pargs.action=='ls':
+            ssh_config_obj = read_ssh_config(ssh_config_path)
+            import ipdb; ipdb.set_trace()
+            print(ssh_config_obj.config())
+
         else:
             # raise NotImplementedError()
             print('Arg out of {set, update} provided assuming an SSH command.')
-            ssh_config_obj = read_ssh_config('/Users/jakub/.ssh/config')
+            ssh_config_obj = read_ssh_config(ssh_config_path)
             target = self.app.pargs.action
             if not target in ssh_config_obj.hosts_: raise Exception(f'Host {target} not in configured hosts.')
             else:
