@@ -2,10 +2,11 @@ from ..ext.hist import hist_tail
 import os
 
 def run_command(n_lines: list):
-    # TODO: what if non-default n lines has been pased to hist
-    df = hist_tail(20)
+    # TODO: propagate that last line in n_lines is the # of lines used
+    # maybe add a check for 1 num to use default (20)
+    df = hist_tail(n_lines[-1])
     exec_line = ''
-    for cmd in n_lines:
+    for cmd in n_lines[:-1]:
         exec_line += f"{df.iloc[cmd].Command}"
         exec_line += ' && '
 
